tteo_coresystems

package
v0.0.0-...-5a25bdc Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 17, 2025 License: MIT Imports: 5 Imported by: 6

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type IntegrationSystem

type IntegrationSystem struct{}

IntegrationSystem handles position and rotation integration based on dynamics

func (IntegrationSystem) Run

Run performs integration of positions and rotations based on dynamic properties

type TransformSystem

type TransformSystem struct{}

TransformSystem updates world coordinates for shapes based on position, rotation, and scale

func (TransformSystem) Run

func (TransformSystem) Run(scene blueprint.Scene, dt float64) error

Run processes all entities with Shape components and updates their world vertices

Jump to