Documentation
¶
Index ¶
- func InitConversation(scene coldbrew.Scene, convo *dialogue.Conversation, fontFace *text.GoTextFace, ...) bool
- type BackgroundScrollSystem
- type CameraBorderLockSystem
- type CameraSceneAssignerSystem
- type DialogueSoundSystem
- type DialogueTextSystem
- type InputBufferSystem
- type InputSenderSystem
- type SplitScreenLayoutSystem
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func InitConversation ¶
func InitConversation(scene coldbrew.Scene, convo *dialogue.Conversation, fontFace *text.GoTextFace, maxWidth float64) bool
Types ¶
type BackgroundScrollSystem ¶
type BackgroundScrollSystem struct{}
BackgroundScrollSystem handles parallax scrolling effects for backgrounds based on camera movement
func (BackgroundScrollSystem) Run ¶
func (BackgroundScrollSystem) Run(cli coldbrew.LocalClient, scene coldbrew.Scene) error
type CameraBorderLockSystem ¶
type CameraBorderLockSystem struct{}
CameraBorderLockSystem ensures cameras stay within scene boundaries
func (CameraBorderLockSystem) Run ¶
func (sys CameraBorderLockSystem) Run(cli coldbrew.LocalClient, scene coldbrew.Scene) error
Run implements the system that constrains camera movement to scene boundaries
type CameraSceneAssignerSystem ¶
type CameraSceneAssignerSystem struct {
// contains filtered or unexported fields
}
CameraSceneAssignerSystem manages cameras across scenes. It uses the 'CameraIndex' component to determine which cameras should be active. When all scenes are inactive (loading or similar states), the system will only keep the first camera active to display loaders or other UI elements.
type DialogueSoundSystem ¶
func (DialogueSoundSystem) Run ¶
func (sys DialogueSoundSystem) Run(cli coldbrew.LocalClient, scene coldbrew.Scene) error
type DialogueTextSystem ¶
type DialogueTextSystem struct {
TEXT_REVEAL_DELAY_IN_TICKS int
FONT_SIZE int
FONT_FACE *text.GoTextFace
MAX_LINE_WIDTH int
}
func (DialogueTextSystem) Run ¶
func (sys DialogueTextSystem) Run(cli coldbrew.LocalClient, scene coldbrew.Scene) error
type InputBufferSystem ¶
type InputBufferSystem struct{}
InputBufferSystem extracts client inputs and passes them to the core system components as StampedActions
type InputSenderSystem ¶
type InputSenderSystem struct{}
InputSenderSystem collects inputs from local receivers and sends them over the network as StampedActions
type SplitScreenLayoutSystem ¶
type SplitScreenLayoutSystem struct {
// contains filtered or unexported fields
}
SplitScreenLayoutSystem manages camera layouts based on resolution, window size and active camera count